@@ -36,7 +36,7 @@ BEAM::~BEAM ()
   weap    = NULL;
   _global = NULL;
   _env    = NULL;
-   delete(points);
+   delete [] points;
 }
 
 void tracePath (int *targetX, int *targetY, GLOBALDATA *global, ENVIRONMENT *env, int minRange, double xpos, double ypos, int angle)
