@@ -15,7 +15,7 @@ BUTTON::BUTTON(GLOBALDATA *global, ENVIRONMENT *env, int x1, int y1,
   location.x = x1;
   location.y = y1;
   text = text1;
-  click = (SAMPLE *)_global->SOUND[8].dat;
+  click = (SAMPLE *)_global->sounds[8];
   bmp = bmp1;
   hover = hover1;
   depressed = depressed1;
