@@ -1,4 +1,3 @@
-#pragma once
 #ifndef BUTTON_HEADER_
 #define BUTTON_HEADER_
 
@@ -7,12 +6,6 @@
 
 class BUTTON
   {
-  private:
-    // empty ctor, copy-ctor and assign operator are private, so the compiler won't create implicit ones!
-    inline BUTTON () { }
-    inline BUTTON (BUTTON &sourceButton _UNUSED) { }
-    inline const BUTTON& operator= (const BUTTON &sourceButton) { return(sourceButton); }
-
     GLOBALDATA *_global;
     ENVIRONMENT *_env;
 
