@@ -382,10 +382,12 @@ void Create_Sky(ENVIRONMENT *env, GLOBALDATA *global)
     {
       if ( env->sky ) destroy_bitmap(env->sky);
 #ifdef THREADS
-      if (env->waiting_sky)
+      if (env->get_waiting_sky())
       {
-           env->sky = env->waiting_sky;
+           env->sky = env->get_waiting_sky();
+           env->lock(env->waiting_sky_lock);
            env->waiting_sky = NULL;
+           env->unlock(env->waiting_sky_lock);
       }
       else
       {
