@@ -115,12 +115,14 @@ class ENVIRONMENT
     double	*height;
     BITMAP	*db, *terrain, *sky;
     BITMAP *waiting_sky, *waiting_terrain;     // sky saved in background
+    #ifdef THREADS
     pthread_mutex_t* waiting_terrain_lock;
     pthread_mutex_t* waiting_sky_lock;
     void destroy_lock(pthread_mutex_t* lock);
     pthread_mutex_t* init_lock(pthread_mutex_t* lock);
     void lock(pthread_mutex_t* lock);
     void unlock(pthread_mutex_t* lock);
+    #endif
     BITMAP* get_waiting_sky();
     BITMAP* get_waiting_terrain();
     const gradient **my_sky_gradients, **my_land_gradients;
