@@ -1089,6 +1089,10 @@ int Display_Tank_Bitmap(ENVIRONMENT *env, int xpos, int ypos, void *image_number
           use_tank_bitmap = 15;
           use_turret_bitmap = 8;
           break;
+        case MINI_TANK:
+          use_tank_bitmap = 16;
+          use_turret_bitmap = 8;
+          break;
         default:
           use_tank_bitmap = 0;
           use_turret_bitmap = 0;
