@@ -32,6 +32,12 @@
 
 #define SPEED_RANGE 6
 
+#ifndef TRUE
+#define TRUE 1
+#endif
+#ifndef FALSE
+#define FALSE 0
+#endif
 
 class FLOATTEXT: public VIRTUAL_OBJECT
   {
@@ -39,7 +45,7 @@ class FLOATTEXT: public VIRTUAL_OBJECT
     // empty ctor, copy-ctor and assign operator are private, so the compiler won't create implicit ones!
     // inline const FLOATTEXT& operator= (const FLOATTEXT &sourceText) { return(sourceText); }
 
-    char _text[80];
+    char *_text;
     int	_color;
     int _halfColor; // for shadowd text!
     int original_x;
@@ -62,7 +68,7 @@ class FLOATTEXT: public VIRTUAL_OBJECT
 
     int	applyPhysics ();
     void draw (BITMAP *dest);
-    void set_text (char * text);
+    int set_text (char * text);
     void set_pos (int x, int y);
     void set_color (int color);
     void set_speed(double x_speed, double y_speed);
