@@ -39,7 +39,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
     int count;
     int winner = -1, done = FALSE;
     int stuff_happening = FALSE;
-    int AI_clock;
+    int AI_clock = 0;
     int fire = FALSE;
     int roundEndCount = 0;
     int game_speed = (int) global->frames_per_second * GAME_SPEED / 60;
@@ -278,7 +278,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
 
            // update position
            a_tank->pen = 0;
-           a_tank->applyPhysics(global);
+           a_tank->applyPhysics();
 
            if ( (a_tank->l <= 0) && (! explosion_in_progress) )    // dead tank
            {
@@ -393,14 +393,14 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
               if ( my_tank == global->players[count]->tank )
               {
                  text_bounce += text_delta;
-                 global->players[count]->tank->draw(env->db, text_bounce / 4);
+                 global->players[count]->tank->drawTank(env->db, text_bounce / 4);
                  if ( (text_bounce > MAX_TEXT_BOUNCE) ||
                       (text_bounce < 1) )
                     text_delta = -text_delta;
               }
                  
               else
-                 global->players[count]->tank->draw(env->db, 0);
+                 global->players[count]->tank->drawTank(env->db, 0);
               global->players[count]->tank->update();
            }
         }
