@@ -122,7 +122,7 @@ MENUDESC mainMenu;
 
 if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPANISH) || (global->language == LANGUAGE_ITALIAN) )
   {
-    MENUENTRY physicsOpts[8] =
+    static MENUENTRY physicsOpts[8] =
     {
       { "Gravity", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Viscosity", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 60},
@@ -135,7 +135,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
     };
     MENUDESC physicsMenu = { "Physics", 8, physicsOpts, TRUE, FALSE};
 
-    MENUENTRY weatherOpts[7] =
+    static MENUENTRY weatherOpts[7] =
     {
       { "Meteor Showers", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1, 0, meteorText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Lightning", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0, lightningText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -148,7 +148,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
     MENUDESC weatherMenu = { "Weather", 7, weatherOpts, TRUE, FALSE};
 
 
-    MENUENTRY soundOpts[3] =
+    static MENUENTRY soundOpts[3] =
     {
       { "All Sound", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Sound Driver", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -157,7 +157,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
    MENUDESC soundMenu = { "Sound", 3, soundOpts, TRUE, FALSE};
 
 
-    MENUENTRY graphicsOpts[12] =
+    static MENUENTRY graphicsOpts[12] =
     {
       { "Full Screen", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Dithering", NULL, WHITE, &global->ditherGradients, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
@@ -174,7 +174,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
     };
     MENUDESC graphicsMenu = { "Graphics", 12, graphicsOpts, TRUE, FALSE};
 
-    MENUENTRY financeOpts[9] =
+    static MENUENTRY financeOpts[9] =
     {
       { "Starting Money", NULL, WHITE, (double*)&global->startmoney, NULL, "%2.0f", 0, 200000, 5000, 20000, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Interest Rate", NULL, WHITE, (double*)&global->interest, NULL, "%2.2f", 1.0, 1.5, 0.05, 1.25, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -188,7 +188,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
     };
     MENUDESC financeMenu = { "Money", 9, financeOpts, TRUE, FALSE};
 
-    MENUENTRY networkOpts[5] =
+    static MENUENTRY networkOpts[5] =
     {
        {  "Check Updates", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
        {  "Networking", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -205,7 +205,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
     void *pnetworkMenu =        &networkMenu;
     void *pSoundMenu   =        &soundMenu;
 
-    MENUENTRY mainOpts[12] =
+    static MENUENTRY mainOpts[12] =
     {
       { "Physics", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
       { "Weather", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
@@ -231,7 +231,7 @@ if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPA
 
 if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
   {
-    MENUENTRY physicsOpts[8] =
+    static MENUENTRY physicsOpts[8] =
     {
       { "Gravidade", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Viscosidade", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 60},
@@ -245,7 +245,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
     };
     MENUDESC physicsMenu = { "Física", 7, physicsOpts, TRUE, FALSE};
 
-    MENUENTRY weatherOpts[7] =
+    static MENUENTRY weatherOpts[7] =
     {
       { "Chuvas de Meteoro", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1,
         0, meteorText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3,
@@ -271,7 +271,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
                              TRUE, FALSE
                            };
 
-    MENUENTRY soundOpts[3] =
+    static MENUENTRY soundOpts[3] =
     {
       { "Efeitos de Som", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Sistema de Som", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -280,7 +280,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
    MENUDESC soundMenu = { "Som", 3, soundOpts, TRUE, FALSE};
 
 
-    MENUENTRY graphicsOpts[12] =
+    static MENUENTRY graphicsOpts[12] =
     {
       { "Tela Cheia", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Pontilhamento", NULL, WHITE, &global->ditherGradients, NULL, "%s",
@@ -311,7 +311,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
     };
     MENUDESC graphicsMenu = { "Gráficos", 12, graphicsOpts, TRUE, FALSE};
 
-    MENUENTRY financeOpts[9] =
+    static MENUENTRY financeOpts[9] =
     {
       { "Dinheiro inicial", NULL, WHITE, (double*)&global->startmoney, NULL,
         "%2.0f", 0, 200000, 5000, 20000, NULL, OPTION_DOUBLETYPE, FALSE,
@@ -342,7 +342,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
     };
     MENUDESC financeMenu = { "Dinheiro", 9, financeOpts, TRUE, FALSE};
 
-    MENUENTRY networkOpts[3] =
+    static MENUENTRY networkOpts[3] =
     {
        {  "Procurar actualizações", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
        {  "Activar Rede", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -358,7 +358,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
     void *pnetworkMenu  =       &networkMenu;
     void *pSoundMenu    =       &soundMenu;
 
-    MENUENTRY mainOpts[12] =
+    static MENUENTRY mainOpts[12] =
     {
       { "Física", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0,
         0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3,
@@ -404,7 +404,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
 // french
 if (global->language == LANGUAGE_FRENCH)
   {
-    MENUENTRY physicsOpts[8] =
+    static MENUENTRY physicsOpts[8] =
     {
       { "Gravité", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Viscosité", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 40},
@@ -418,7 +418,7 @@ if (global->language == LANGUAGE_FRENCH)
     };
     MENUDESC physicsMenu = { "Physique", 7, physicsOpts, TRUE, FALSE};
 
-    MENUENTRY weatherOpts[7] =
+    static MENUENTRY weatherOpts[7] =
     {
       { "Orages de météorites", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1, 0, meteorText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Éclairs", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0, lightningText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -430,7 +430,7 @@ if (global->language == LANGUAGE_FRENCH)
     };
     MENUDESC weatherMenu = { "Météo", 7, weatherOpts, TRUE, FALSE};
 
-    MENUENTRY soundOpts[3] =
+    static MENUENTRY soundOpts[3] =
     {
       { "Effets Sonores", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Système de Son", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -439,7 +439,7 @@ if (global->language == LANGUAGE_FRENCH)
    MENUDESC soundMenu = { "Sound", 3, soundOpts, TRUE, FALSE};
 
 
-    MENUENTRY graphicsOpts[12] =
+    static MENUENTRY graphicsOpts[12] =
     {
       { "Full Screen", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Tramage", NULL, WHITE, &global->ditherGradients, NULL, "%s", 0, 1, 1, 1, onOffText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
@@ -456,7 +456,7 @@ if (global->language == LANGUAGE_FRENCH)
     };
     MENUDESC graphicsMenu = { "Graphismes", 12, graphicsOpts, TRUE, FALSE};
 
-    MENUENTRY financeOpts[9] =
+    static MENUENTRY financeOpts[9] =
     {
       { "Somme de départ", NULL, WHITE, (double*)&global->startmoney, NULL, "%2.0f", 0, 200000, 5000, 20000, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Taux d'intérêt", NULL, WHITE, (double*)&global->interest, NULL, "%2.2f", 1.0, 1.5, 0.05, 1.25, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -471,7 +471,7 @@ if (global->language == LANGUAGE_FRENCH)
     };
     MENUDESC financeMenu = { "Finances", 9, financeOpts, TRUE, FALSE};
 
-    MENUENTRY networkOpts[3] =
+    static MENUENTRY networkOpts[3] =
     {
        {  "Check Updates", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
        {  "Networking", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -488,7 +488,7 @@ if (global->language == LANGUAGE_FRENCH)
     void *pnetworkMenu  =       &networkMenu;
     void *pSoundMenu    =       &soundMenu;
 
-    MENUENTRY mainOpts[12] =
+    static MENUENTRY mainOpts[12] =
     {
       { "Physique", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
       { "Météo", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
@@ -515,7 +515,7 @@ if (global->language == LANGUAGE_FRENCH)
 
 if (global->language == LANGUAGE_GERMAN)
   {
-    MENUENTRY physicsOpts[8] =
+    static MENUENTRY physicsOpts[8] =
     {
       { "Gravitation", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Reibung", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 60},
@@ -528,7 +528,7 @@ if (global->language == LANGUAGE_GERMAN)
     };
     MENUDESC physicsMenu = { "Physik", 8, physicsOpts, TRUE, FALSE};
 
-    MENUENTRY weatherOpts[7] =
+    static MENUENTRY weatherOpts[7] =
     {
       { "Meteoritenregen", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1, 0, meteorText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Gewitter", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0, lightningText_de,OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -540,7 +540,7 @@ if (global->language == LANGUAGE_GERMAN)
     };
     MENUDESC weatherMenu = { "Wetter", 7, weatherOpts, TRUE, FALSE};
 
-    MENUENTRY soundOpts[3] =
+    static MENUENTRY soundOpts[3] =
     {
       { "Alle Sounds", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Sound Treiber", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -550,7 +550,7 @@ if (global->language == LANGUAGE_GERMAN)
 
 
 
-    MENUENTRY graphicsOpts[12] =
+    static MENUENTRY graphicsOpts[12] =
     {
       { "Full Screen", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Dithering", NULL, WHITE, &global->ditherGradients, NULL, "%s", 0, 1, 1, 1, onOffText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
@@ -568,7 +568,7 @@ if (global->language == LANGUAGE_GERMAN)
     MENUDESC graphicsMenu = { "Grafik", 12, graphicsOpts, TRUE, FALSE};
 
 
-    MENUENTRY financeOpts[9] =
+    static MENUENTRY financeOpts[9] =
     {
       { "Startgeld", NULL, WHITE, (double*)&global->startmoney, NULL, "%2.0f", 0, 200000, 5000, 20000, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Zinssatz", NULL, WHITE, (double*)&global->interest, NULL, "%2.2f", 1.0, 1.5, 0.05,1.25, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -583,7 +583,7 @@ if (global->language == LANGUAGE_GERMAN)
     };
     MENUDESC financeMenu = { "Geld", 9, financeOpts, TRUE, FALSE};
 
-    MENUENTRY networkOpts[3] =
+    static MENUENTRY networkOpts[3] =
     {
        {  "Auf Aktualisierungen prüfen", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
        {  "Netzwerk", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -599,7 +599,7 @@ if (global->language == LANGUAGE_GERMAN)
     void *pnetworkMenu  =       &networkMenu;
     void *pSoundMenu    =       &soundMenu;
 
-    MENUENTRY mainOpts[12] =
+    static MENUENTRY mainOpts[12] =
     {
       { "Physik", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
       { "Wetter", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
@@ -626,7 +626,7 @@ if (global->language == LANGUAGE_GERMAN)
 
 if (global->language == LANGUAGE_SLOVAK)
   {
-    MENUENTRY physicsOpts[8] =
+    static MENUENTRY physicsOpts[8] =
     {
       { "Gravitácia", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Viskozita", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 60},
@@ -639,7 +639,7 @@ if (global->language == LANGUAGE_SLOVAK)
     };
     MENUDESC physicsMenu = { "Fyzika", 7, physicsOpts, TRUE, FALSE};
 
-    MENUENTRY weatherOpts[7] =
+    static MENUENTRY weatherOpts[7] =
     {
       { "Dážď meteorov", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1, 0, meteorText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Blesky", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0, lightningText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -651,7 +651,7 @@ if (global->language == LANGUAGE_SLOVAK)
     };
     MENUDESC weatherMenu = { "Počasie", 7, weatherOpts, TRUE, FALSE};
 
-    MENUENTRY soundOpts[3] =
+    static MENUENTRY soundOpts[3] =
     {
       { "Všetky zvuky", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Ovládač zvuku", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -661,7 +661,7 @@ if (global->language == LANGUAGE_SLOVAK)
 
 
 
-    MENUENTRY graphicsOpts[12] =
+    static MENUENTRY graphicsOpts[12] =
     {
       { "Na celú obrazovku", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Rozptyl", NULL, WHITE, &global->ditherGradients, NULL, "%s", 0, 1, 1, 1, onOffText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
@@ -678,7 +678,7 @@ if (global->language == LANGUAGE_SLOVAK)
     };
     MENUDESC graphicsMenu = { "Grafika", 12, graphicsOpts, TRUE, FALSE};
 
-    MENUENTRY financeOpts[9] =
+    static MENUENTRY financeOpts[9] =
     {
       { "Peniaze na začiatku", NULL, WHITE, (double*)&global->startmoney, NULL, "%2.0f", 0, 200000, 5000, 20000, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Úroková miera", NULL, WHITE, (double*)&global->interest, NULL, "%2.2f", 1.0, 1.5, 0.05, 1.25, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -694,7 +694,7 @@ if (global->language == LANGUAGE_SLOVAK)
     MENUDESC financeMenu = { "Peniaze", 9, financeOpts, TRUE, FALSE};
 
 
-    MENUENTRY networkOpts[3] =
+    static MENUENTRY networkOpts[3] =
     {
        {  "Kontrola aktualizácii", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
        {  "Sieťová hra", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -711,7 +711,7 @@ if (global->language == LANGUAGE_SLOVAK)
     void *pSoundMenu    =       &soundMenu;
 
 
-    MENUENTRY mainOpts[12] =
+    static MENUENTRY mainOpts[12] =
     {
       { "Fyzika", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
       { "Počasie", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
@@ -737,7 +737,7 @@ if (global->language == LANGUAGE_SLOVAK)
 
 if (global->language == LANGUAGE_RUSSIAN)
 {
-    MENUENTRY physicsOpts[8] =
+    static MENUENTRY physicsOpts[8] =
     {
       { "Гравитация", NULL, WHITE, &env->gravity, NULL, "%2.3f", .025, .325, 0.025, .075, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 80},
       { "Сила трения", NULL, WHITE, &env->viscosity, NULL, "%2.2f", .25, 2.0, 0.25, 1.0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 60},
@@ -751,7 +751,7 @@ if (global->language == LANGUAGE_RUSSIAN)
     MENUDESC physicsMenu = { "Физика", 7, physicsOpts, TRUE, FALSE};
 
 
-    MENUENTRY weatherOpts[7] =
+    static MENUENTRY weatherOpts[7] =
     {
       { "Метеоритный дождь", NULL, WHITE, &env->meteors, NULL, "%s", 0, 3, 1, 0, meteorText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Молнии", NULL, WHITE, &env->lightning, NULL, "%s", 0, 3, 1, 0, lightningText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -764,7 +764,7 @@ if (global->language == LANGUAGE_RUSSIAN)
     MENUDESC weatherMenu = { "Погода", 7, weatherOpts, TRUE, FALSE};
 
 
-    MENUENTRY soundOpts[3] =
+    static MENUENTRY soundOpts[3] =
     {
       { "All Sound", NULL, WHITE, &global->sound, NULL, "%s", 0, 1, 1, 1, onOffText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Sound Driver", NULL, WHITE, &global->sound_driver, NULL, "%s", 0, 5, 1, 0, soundDriver, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -773,7 +773,7 @@ if (global->language == LANGUAGE_RUSSIAN)
    MENUDESC soundMenu = { "Sound", 3, soundOpts, TRUE, FALSE};
 
 
-    MENUENTRY graphicsOpts[12] =
+    static MENUENTRY graphicsOpts[12] =
     {
       { "Full Screen", NULL, WHITE, &global->full_screen, NULL, "%s", 0, 1, 1, 0, onOffText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 108},
       { "Сглаживание", NULL, WHITE, &global->ditherGradients, NULL, "%s", 0, 1, 1, 1, onOffText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
@@ -791,7 +791,7 @@ if (global->language == LANGUAGE_RUSSIAN)
     MENUDESC graphicsMenu = { "Графика", 12, graphicsOpts, TRUE, FALSE};
 
 
-    MENUENTRY financeOpts[9] =
+    static MENUENTRY financeOpts[9] =
     {
       { "Начальные деньги", NULL, WHITE, (double*)&global->startmoney, NULL, "%2.0f", 0, 200000, 5000, 20000, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
       { "Банковский процент", NULL, WHITE, (double*)&global->interest, NULL, "%2.2f", 1.0, 1.5, 0.05, 1.25, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
@@ -806,7 +806,7 @@ if (global->language == LANGUAGE_RUSSIAN)
     MENUDESC financeMenu = { "Экономика", 9, financeOpts, TRUE, FALSE};
 
 
-    MENUENTRY networkOpts[3] =
+    static MENUENTRY networkOpts[3] =
     {
        {  "Проверять обновления", NULL, WHITE, (double*) &global->check_for_updates, NULL, "%s", 0, 1, 1, 1, onOffText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 48},
        {  "Networking", NULL, WHITE, (double*) &global->enable_network, NULL, "%s", 0, 1, 1, 1, onOffText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 28},
@@ -822,7 +822,7 @@ if (global->language == LANGUAGE_RUSSIAN)
     void *pSoundMenu    =       &soundMenu;
 
 
-    MENUENTRY mainOpts[12] =
+    static MENUENTRY mainOpts[12] =
     {
       { "Физика", NULL, WHITE, (double*)pPhysicsMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 88},
       { "Погода", NULL, WHITE, (double*)pWeatherMenu, NULL, NULL, 0, 0, 0, 0, NULL, OPTION_MENUTYPE, FALSE, global->halfWidth - 3, global->halfHeight - 68},
