@@ -34,13 +34,20 @@ MISSILE::~MISSILE ()
   weap    = NULL;
 }
 
-MISSILE::MISSILE (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos, double xvel, double yvel,
+MISSILE::MISSILE (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos, 
+                  double xvel, double yvel,
                   int weaponType):PHYSICAL_OBJECT(),weap(NULL)
 {
   setEnvironment (env);
   player = NULL;
   _align = LEFT;
   _global = global;
+  #ifdef NETWORK
+  char buffer[256];
+  sprintf(buffer, "MISSILE %d %d %lf %lf %d", (int)xpos, (int)ypos,
+                  xvel, yvel, weaponType);
+  global->Send_To_Clients(buffer);
+  #endif
   x = xpos;
   y = ypos;
   xv = xvel;
@@ -63,6 +70,7 @@ MISSILE::MISSILE (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos
   _bitmap = (BITMAP *)_global->missile[picpoint];
   physics = 0;
   age = 0;
+  destroy = FALSE;
   if (type >= SML_METEOR && type <= LRG_METEOR)
     {
       angle = rand () % 360;
@@ -122,6 +130,7 @@ int MISSILE::triggerTest ()
 {
   int quell = 1;
   TANK *tank;
+  double old_delta_x = xv;
 
   // Has it hit a tank?
   for (int objCount = 0; (tank = (TANK*)_env->getNextOfClass (TANK_CLASS, &objCount)) && tank; objCount++)
@@ -137,6 +146,7 @@ int MISSILE::triggerTest ()
       quell = 1;
     }
   else if ((y > 0) && (hitSomething || (y >= _global->screenHeight) || (getpixel (_env->terrain, (int)x, (int)y) != PINK)))
+    // else if ( (y > 0) && (hitSomething || (y >= _global->screenHeight) || (_env->surface[(int)x] <= y) ) )
     {
       quell = 0;
       if (type >= SML_ROLLER && type <= DTH_ROLLER && !physics)
@@ -168,14 +178,29 @@ int MISSILE::triggerTest ()
                   xv--;
               else
               {
-              if (getpixel (_env->terrain, (int)x + 1, (int)y + 1) == PINK)
-                xv++;
-              if (getpixel (_env->terrain, (int)x - 1, (int)y + 1) == PINK)
-                xv--;
+                  int can_go_left = FALSE, can_go_right = FALSE;
+                  if (getpixel (_env->terrain, (int)x + 1, (int)y + 1) == PINK)
+                     can_go_right = TRUE;
+                  if (getpixel (_env->terrain, (int)x - 1, (int)y + 1) == PINK)
+                     can_go_left = TRUE;
+
+                  if ( (can_go_left) && (!can_go_right) )
+                  {
+                     xv--;
+                  }
+                  else if ( (! can_go_left) && (can_go_right) )
+                  {
+                     xv++;
+                  }
+                  else if ( (can_go_left) && (can_go_right) )
+                  {
+                     xv = old_delta_x;      // if both are open, continue on old course
+                  }
               }
-              if (xv == 0.0)
-                // if both sides are free (should be impossible, but might be a 1-pixel-peak) the shooting direction decides
+              if (xv == 0.0)     // nothing worked, try something!
+              {
                 xv = yv;
+              }
               yv = 0.0;
               hitSomething = 0;
             }
@@ -352,8 +377,9 @@ int MISSILE::applyPhysics ()
             }
         }
       if ( PHYSICAL_OBJECT::applyPhysics () )
+      {
         detonate = 1;
-
+      }
       if (! detonate)
         detonate = checkPixelsBetweenPrevAndNow ();
 
