@@ -12,15 +12,9 @@
 
 class SATELLITE
   {
-  private:
-    // empty ctor, copy-ctor and assign operator are private, so the compiler won't create implicit ones!
-    inline SATELLITE () { }
-    inline SATELLITE (SATELLITE &sourceSat _UNUSED) { }
-    inline const SATELLITE& operator= (const SATELLITE &sourceSat) { return(sourceSat); }
-
   public:
     int x, y;
-    int xv;
+    int xv, previous_x;
     GLOBALDATA *_global;
     ENVIRONMENT *_env;
 
