@@ -544,7 +544,7 @@ void TANK::framelyAccounting ()
      delta_phase = -delta_phase;
 }
 
-int TANK::applyPhysics (GLOBALDATA *global)
+int TANK::applyPhysics ()
 {
   int stable = 0;
   int landed_on_tank;
@@ -571,7 +571,7 @@ int TANK::applyPhysics (GLOBALDATA *global)
       int pixelCol = getpixel (_env->terrain, (int)x, (int)y + (TANKHEIGHT - TANKSAG));
 
       // check to see if we have landed on another tank -- Jesse
-      landed_on_tank = tank_on_tank ( global );
+      landed_on_tank = tank_on_tank ( _global );
 
       // we are falling and have hit the bottom of the screen or fallen onto dirt or on a tank
       if ((l > 0) && (yv > 0) && ((y >= _global->screenHeight - TANKHEIGHT) ||
@@ -737,7 +737,7 @@ void TANK::printHealth (int offset)
   }
 }
 
-void TANK::draw (BITMAP *dest, int healthOffset)
+void TANK::drawTank (BITMAP *dest, int healthOffset)
 {
   int turretAngle;
 
@@ -802,6 +802,12 @@ void TANK::draw (BITMAP *dest, int healthOffset)
           turret_y = y;
           turret_x = x;
           break;
+        case MINI_TANK:
+          use_tank_bitmap = 16;
+          use_turret_bitmap = 9;
+          turret_y = y;
+          turret_x = x;
+          break;
         default:
           use_tank_bitmap = 0;
           use_turret_bitmap = 0;
@@ -1151,7 +1157,7 @@ void TANK::activateCurrentSelection ()
               xv -= 0.3;
          }
 
-         applyPhysics(_global);
+         applyPhysics();
       }
 
       else if ( itemNum == ITEM_FAN )
