@@ -71,7 +71,7 @@ class TANK: public PHYSICAL_OBJECT
     int	get_heaviest_shield ();
     void	boost_up_shield ();
     void	reactivate_shield ();
-    void	draw (BITMAP *dest, int healthOffset);
+    void	drawTank (BITMAP *dest, int healthOffset);
     void	printHealth (int offset);
     void	update ();
     void	requireUpdate ();
@@ -85,7 +85,7 @@ class TANK: public PHYSICAL_OBJECT
     }
     virtual void setEnvironment(ENVIRONMENT *env);
     void	applyDamage ();
-    int	applyPhysics (GLOBALDATA *global);
+    int	applyPhysics ();
     void	repulse (double xpos, double ypos, double *xaccel, double *yaccel, int aWeaponType);
     int	howBuried ();
     int	shootClearance (int targetAngle, int minimumClearance = MAX_OVERSHOOT);
