@@ -9,8 +9,9 @@ int Team_Won(GLOBALDATA *global)
   bool all_sith = true;
   int current_player = 0;
   int my_team = 1;
+  int player_count = 0;
 
-  while ((all_jedi || all_sith) && current_player < global->numPlayers)
+  while ((all_jedi || all_sith) && ( current_player < global->numPlayers) )
     {
       if ( (global->players[current_player]->tank) &&
            (global->players[current_player]->tank->l) )
@@ -21,10 +22,12 @@ int Team_Won(GLOBALDATA *global)
 
           if ( (my_team == TEAM_SITH) || (my_team == TEAM_NEUTRAL) )
             all_jedi = false;
+          player_count++;
         }
       current_player++;
     }
 
+  if (! player_count) return NO_WIN;
   if (all_jedi) return JEDI_WIN;
   else if (all_sith) return SITH_WIN;
   else return NO_WIN;
